BERT backend: HuggingFace Hub model load, tokenize, forward pass, masked mean pooling, and L2 normalization.
Structs
- Bert
Backend - BERT-based embedding backend backed by
candle_transformers::BertModel.
BERT backend: HuggingFace Hub model load, tokenize, forward pass, masked mean pooling, and L2 normalization.
candle_transformers::BertModel.